train_tools.data_utils.custom.NormalizeImage — spacr 0.5.0 documentation

# train_tools.data_utils.custom.NormalizeImage

## Module Contents

class train_tools.data_utils.custom.NormalizeImage.CustomNormalizeImage(percentiles=[0, 99.5], channel_wise=False)

  Bases: `monai.transforms.transform.Transform`

  Normalize the image.

  channel_wise = False

class train_tools.data_utils.custom.NormalizeImage.CustomNormalizeImaged(keys: monai.config.KeysCollection, percentiles=[1, 99], channel_wise: bool = False, allow_missing_keys: bool = False)

  Bases: `monai.transforms.compose.MapTransform`

  Dictionary-based wrapper of NormalizeImage

  normalizer